@@ -1179,9 +1179,14 @@ class VariableOsLocationDest(LocationHelper, Variable):
         ##########################
         # detect efi specifing
         ##########################
-        if "/boot/efi" in value or "efi" in value:
-            raise VariableError(
-                _("Please specify EFI partition by UEFI option"))
+        if "efi" in value:
+            if self.Get('cl_client_type') == 'gui':
+                raise VariableError(
+                    _("Please specify EFI partition by UEFI parameter in "
+                      "advanced options"))
+            else:
+                raise VariableError(
+                    _("Please specify EFI partition by UEFI option"))
         ##########################
         # detect duplicate mps
         ##########################
